@@ -46,7 +46,7 @@ class AttachmentEditDialog : public QDialog
     Q_OBJECT
 public:
     AttachmentEditDialog(AttachmentIconItem *item, QWidget *parent, bool modal = true);
-    virtual ~AttachmentEditDialog();
+    ~AttachmentEditDialog() override;
     void accept() override;
 
 protected Q_SLOTS:
@@ -57,10 +57,10 @@ protected Q_SLOTS:
 
 private:
     KCalCore::Attachment::Ptr mAttachment;
-    AttachmentIconItem *mItem;
+    AttachmentIconItem *mItem = nullptr;
     QMimeType mMimeType;
-    Ui::AttachmentEditDialog *mUi;
-    QPushButton *mOkButton;
+    Ui::AttachmentEditDialog *mUi = nullptr;
+    QPushButton *mOkButton = nullptr;
 };
 }
 
